@@ -1,31 +1,22 @@
 /*
  * This file is part of GPaste.
  *
- * Copyright (c) 2010-2018, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
+ * Copyright (c) 2010-2019, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
-/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
-
-const Lang = imports.lang;
 
 const PopupMenu = imports.ui.popupMenu;
 
-const Clutter = imports.gi.Clutter;
-const Pango = imports.gi.Pango;
-const St = imports.gi.St;
-
-const GPaste = imports.gi.GPaste;
+const { Clutter, GObject, GPaste, Pango, St } = imports.gi;
 
 const ExtensionUtils = imports.misc.extensionUtils;
 const Me = ExtensionUtils.getCurrentExtension();
 
 const DeleteItemPart = Me.imports.deleteItemPart;
 
-var GPasteItem = new Lang.Class({
-    Name: 'GPasteItem',
-    Extends: PopupMenu.PopupMenuItem,
-
-    _init: function(client, size, index) {
-        this.parent("");
+var GPasteItem = GObject.registerClass(
+class GPasteItem extends PopupMenu.PopupMenuItem {
+    _init(client, size, index) {
+        super._init("");
 
         this._client = client;
 
@@ -37,33 +28,33 @@ var GPasteItem = new Lang.Class({
         }
 
         this.connect('activate', this._onActivate.bind(this));
-        this.actor.connect('key-press-event', this._onKeyPressed.bind(this));
+        this.connect('key-press-event', this._onKeyPressed.bind(this));
 
         this._deleteItem = new DeleteItemPart.GPasteDeleteItemPart(client, index);
-        this.actor.add(this._deleteItem.actor, { expand: true, x_align: St.Align.END });
+        this.add(this._deleteItem.actor, { expand: true, x_align: St.Align.END });
 
         this.label.clutter_text.ellipsize = Pango.EllipsizeMode.END;
         this.setTextSize(size);
 
         this.setIndex(index);
-    },
+    }
 
-    showIndex: function(state) {
+    showIndex(state) {
         if (state) {
             if (!this._indexLabelVisible) {
-                this.actor.insert_child_at_index(this._indexLabel, 1);
+                this.insert_child_at_index(this._indexLabel, 1);
             }
         } else if (this._indexLabelVisible) {
-            this.actor.remove_child(this._indexLabel);
+            this.remove_child(this._indexLabel);
         }
         this._indexLabelVisible = state;
-    },
+    }
 
-    refresh: function() {
+    refresh() {
         this.setIndex(this._index);
-    },
+    }
 
-    setIndex: function(index) {
+    setIndex(index) {
         const oldIndex = this._index || -1;
         this._index = index;
 
@@ -83,24 +74,24 @@ var GPasteItem = new Lang.Class({
                 }
                 this.label.clutter_text.set_text(text);
                 if (oldIndex == -1) {
-                    this.actor.show();
+                    this.show();
                 }
             });
         } else {
             this.label.clutter_text.set_text(null);
-            this.actor.hide();
+            this.hide();
         }
-    },
+    }
 
-    setTextSize: function(size) {
+    setTextSize(size) {
         this.label.clutter_text.max_length = size;
-    },
+    }
 
-    _onActivate: function(actor, event) {
+    _onActivate(actor, event) {
         this._client.select(this._index, null);
-    },
+    }
 
-    _onKeyPressed: function(actor, event) {
+    _onKeyPressed(actor, event) {
         const symbol = event.get_key_symbol();
         if (symbol == Clutter.KEY_space || symbol == Clutter.KEY_Return) {
             this.activate(event);
